@@ -14,10 +14,6 @@
 # limitations under the License.
 """Useful commands for interacting with the Cloud Filestore API."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
-
 from apitools.base.py import list_pager
 from googlecloudsdk.api_lib.compute import utils
 from googlecloudsdk.api_lib.util import apis
@@ -72,6 +68,14 @@ class InvalidNameError(Error):
   """Raised when an invalid file share name value is provided."""
 
 
+class InvalidDisconnectManagedADError(Error):
+  """Raised when an invalid disconnect managed AD value is provided."""
+
+
+class InvalidDisconnectLdapError(Error):
+  """Raised when an invalid LDAP value is provided."""
+
+
 class FilestoreClient(object):
   """Wrapper for working with the file API."""
 
@@ -289,6 +293,7 @@ class FilestoreClient(object):
       source_instance=None,
       deletion_protection_enabled=None,
       deletion_protection_reason=None,
+      backend_type=None,
   ):
     """Parses the command line arguments for Create into a config.
 
@@ -309,6 +314,7 @@ class FilestoreClient(object):
       source_instance: The replication source of the instance.
       deletion_protection_enabled: bool, whether to enable deletion protection.
       deletion_protection_reason: The reason for enabling deletion protection.
+      backend_type: The backend type of the instance (Compute or Filestore).
 
     Returns:
       The configuration that will be used as the request body for creating a
@@ -324,6 +330,10 @@ class FilestoreClient(object):
     # In case of Beta API, protocol is never 'None' (the default is 'NFS_V3').
     if protocol:
       instance.protocol = protocol
+    # 'instance.backendType' is a member of 'instance' structure only in
+    # Beta API.
+    if backend_type:
+      instance.backendType = backend_type
     # 'instance.directoryServices' is a member of 'instance' structure only in
     # Beta API.
     if managed_ad:
@@ -381,6 +391,8 @@ class FilestoreClient(object):
       performance=None,
       managed_ad=None,
       disconnect_managed_ad=None,
+      ldap=None,
+      disconnect_ldap=None,
       clear_nfs_export_options=False,
       deletion_protection_enabled=None,
       deletion_protection_reason=None,
@@ -395,6 +407,8 @@ class FilestoreClient(object):
       performance: The performance configuration for the instance.
       managed_ad: The Managed Active Directory settings of the instance.
       disconnect_managed_ad: Disconnect from Managed Active Directory.
+      ldap: The LDAP configuration of the instance.
+      disconnect_ldap: Disconnect from LDAP.
       clear_nfs_export_options: bool, whether to clear the NFS export options.
       deletion_protection_enabled: bool, whether to enable deletion protection.
       deletion_protection_reason: The reason for enabling deletion protection.
@@ -415,6 +429,8 @@ class FilestoreClient(object):
         performance=performance,
         managed_ad=managed_ad,
         disconnect_managed_ad=disconnect_managed_ad,
+        ldap=ldap,
+        disconnect_ldap=disconnect_ldap,
         clear_nfs_export_options=clear_nfs_export_options,
         deletion_protection_enabled=deletion_protection_enabled,
         deletion_protection_reason=deletion_protection_reason,
@@ -551,6 +567,7 @@ class FilestoreClient(object):
           accessMode=access_mode,
           squashMode=squash_mode,
           securityFlavors=security_flavors_list,
+          network=nfs_export_option.get('network', None),
       )
       nfs_export_configs.append(nfs_export_config)
     return nfs_export_configs
@@ -673,6 +690,8 @@ class AlphaFilestoreAdapter(object):
       performance=None,
       managed_ad=None,
       disconnect_managed_ad=None,
+      ldap=None,
+      disconnect_ldap=None,
       clear_nfs_export_options=False,
       deletion_protection_enabled=None,
       deletion_protection_reason=None,
@@ -712,7 +731,22 @@ class AlphaFilestoreAdapter(object):
 
     if managed_ad:
       self.ParseManagedADIntoInstance(instance_config, managed_ad)
+    if ldap:
+      self.ParseLdapIntoInstance(instance_config, ldap)
+    if disconnect_ldap:
+      if not getattr(instance_config.directoryServices, 'ldap', None):
+        raise InvalidDisconnectLdapError(
+            '`--disconnect-ldap` must be used when ldap is connected.'
+        )
+      instance_config.directoryServices = None
     if disconnect_managed_ad:
+      if not getattr(
+          instance_config.directoryServices, 'managedActiveDirectory', None
+      ):
+        raise InvalidDisconnectManagedADError(
+            '`--disconnect-managed-ad` must be used when managed-ad is'
+            ' connected.'
+        )
       instance_config.directoryServices = None
 
     if deletion_protection_enabled is not None:
@@ -804,18 +838,18 @@ class BetaFilestoreAdapter(AlphaFilestoreAdapter):
 
     Args:
       instance: The filestore instance struct.
-      managed_ad: The managed_ad cli paramters
+      managed_ad: The --managed-ad flag value.
 
     Raises:
       InvalidArgumentError: If managed_ad argument constraints are violated.
     """
     domain = managed_ad.get('domain')
     if domain is None:
-      raise InvalidArgumentError('Domain parameter is missing in --managed_ad.')
+      raise InvalidArgumentError('Domain parameter is missing in --managed-ad.')
     computer = managed_ad.get('computer')
     if computer is None:
       raise InvalidArgumentError(
-          'Computer parameter is missing in --managed_ad.'
+          'Computer parameter is missing in --managed-ad.'
       )
 
     instance.directoryServices = self.messages.DirectoryServicesConfig(
@@ -836,13 +870,13 @@ class BetaFilestoreAdapter(AlphaFilestoreAdapter):
     """
     domain = ldap.get('domain')
     if domain is None:
-      raise InvalidArgumentError('Domain parameter is missing in --ldap.')
+      raise InvalidArgumentError('Domain parameter is missing in `--ldap`.')
     servers = ldap.get('servers')
     if servers is None:
-      raise InvalidArgumentError('Servers parameter is missing in --ldap.')
+      raise InvalidArgumentError('Servers parameter is missing in `--ldap`.')
     servers = servers.split(',')
-    usersou = ldap.get('users_ou')
-    groupsou = ldap.get('groups_ou')
+    usersou = ldap.get('users-ou')
+    groupsou = ldap.get('groups-ou')
     # usersou and groupsou are optional
 
     instance.directoryServices = self.messages.DirectoryServicesConfig(
@@ -966,6 +1000,60 @@ class FilestoreAdapter(BetaFilestoreAdapter):
       )
       instance.fileShares.append(file_share_config)
 
+  def ParseManagedADIntoInstance(self, instance, managed_ad):
+    """Parses managed-ad configs into an instance message.
+
+    Args:
+      instance: The filestore instance struct.
+      managed_ad: The --managed-ad flag value.
+
+    Raises:
+      InvalidArgumentError: If managed_ad argument constraints are violated.
+    """
+    domain = managed_ad.get('domain')
+    if domain is None:
+      raise InvalidArgumentError('Domain parameter is missing in --managed-ad.')
+    computer = managed_ad.get('computer')
+    if computer is None:
+      raise InvalidArgumentError(
+          'Computer parameter is missing in --managed-ad.'
+      )
+
+    instance.directoryServices = self.messages.DirectoryServicesConfig(
+        managedActiveDirectory=self.messages.ManagedActiveDirectoryConfig(
+            domain=domain, computer=computer
+        )
+    )
+
+  def ParseLdapIntoInstance(self, instance, ldap):
+    """Parses ldap configs into an instance message.
+
+    Args:
+      instance: The filestore instance struct.
+      ldap: The ldap cli parameters
+
+    Raises:
+      InvalidArgumentError: If ldap argument constraints are violated.
+    """
+    domain = ldap.get('domain')
+    if domain is None:
+      raise InvalidArgumentError('Domain parameter is missing in `--ldap`.')
+    servers = ldap.get('servers')
+    if servers is None:
+      raise InvalidArgumentError('Servers parameter is missing in `--ldap`.')
+    servers = servers.split(',')
+    usersou = ldap.get('users-ou')
+    groupsou = ldap.get('groups-ou')
+    # usersou and groupsou are optional
+
+    instance.directoryServices = self.messages.DirectoryServicesConfig(
+        ldap=self.messages.LdapConfig(
+            domain=domain,
+            servers=servers,
+            usersOu=usersou,
+            groupsOu=groupsou,
+        )
+    )
 
 def GetFilestoreRegistry(api_version=V1_API_VERSION):
   registry = resources.REGISTRY.Clone()
